@@ -2,7 +2,7 @@ package Message::Passing::AMQP;
 use Moose ();
 use namespace::autoclean;
 
-our $VERSION = "0.002";
+our $VERSION = "0.003";
 $VERSION = eval $VERSION;
 
 1;
@@ -14,11 +14,11 @@ Message::Passing::AMQP - input and output message-pass messages via AMQP.
 =head1 SYNOPSIS
 
     # Terminal 1:
-    $ message-pass --input STDIN --output AMQP --output_options '{"exchange_name":"test"}'
+    $ message-pass --input STDIN --output AMQP --output_options '{"exchange_name":"test","hostname":"127.0.0.1","username":"guest","password":"guest"}'
     {"data":{"some":"data"},"@metadata":"value"}
 
     # Terminal 2:
-    $ message-pass --output STDOUT --input AMQP --input_options '{"queue_name":"test","exchange_name":"test"}'
+    $ message-pass --output STDOUT --input AMQP --input_options '{"queue_name":"test","exchange_name":"test","hostname":"127.0.0.1","username":"guest","password":"guest"}'
     {"data":{"some":"data"},"@metadata":"value"}
 
 =head1 DESCRIPTION
